@@ -4,11 +4,11 @@ import logging
 from typing import Iterator, List, Optional
 
 from igraph import Graph
-from wostools import CachedCollection
+from wostools import Collection
 
 __author__ = """Daniel Stiven Valencia Hernadez"""
 __email__ = "dsvalenciah@gmail.com"
-__version__ = "1.0.2"
+__version__ = "2.0.0"
 
 MODE_IN = "IN"
 MODE_OUT = "OUT"
@@ -145,8 +145,12 @@ class Sap:
             not_leaves_anymore["leaf"] = 0
 
         if self.max_leaf_age is not None:
-            ignored = "\n".join(new_graph.vs.select(year_eq=None)["name"])
-            logging.info(f"Ignoring these nodes for year calculations:\n{ignored}")
+            ignored = new_graph.vs.select(year_eq=None)
+            ignored = [
+                {attr: v[attr] for attr in ignored.attributes()} for v in ignored
+            ]
+            if ignored:
+                logging.info(f"Ignoring these nodes for year calculations:\n{ignored}")
             newest_publication_year: int = max(
                 filter(None, new_graph.vs[potential_leaves]["year"])
             )
@@ -156,6 +160,12 @@ class Sap:
             )
             not_leaves_anymore["leaf"] = 0
 
+        if not any(new_graph.vs["leaf"]) and any(new_graph.vs["extended_leaf"]):
+            logging.info(
+                f"Reverting leaf cut policies, as they remove all possible leaves"
+            )
+            new_graph.vs["leaf"] = new_graph.vs["extended_leaf"]
+
         if self.max_leaves is not None:
             sorted_leaves = _sorted_nodes(new_graph, "leaf")
             not_leaves_anymore = sorted_leaves[self.max_leaves :]
@@ -211,12 +221,12 @@ class Sap:
         return graph
 
 
-def load(collection: CachedCollection) -> Iterator[Graph]:
+def load(collection: Collection) -> Iterator[Graph]:
     """
     Takes in a collection of bibliographic records and gets out all the
     connected components of their citation graph.
 
-    :param CachedCollection collection: bibliographic collection
+    :param Collection collection: bibliographic collection
     :return: iterator over the connected components
     """
     metadata = {}
@@ -241,17 +251,18 @@ def load(collection: CachedCollection) -> Iterator[Graph]:
     ).indices
     graph = graph.subgraph(valid_vs)
     graph = _break_loops(graph)
+    yield graph
     for subgraph in graph.decompose(MODE_WEAK, minelements=2):
         if len(subgraph.vs.select(_indegree_gt=0, _outdegree_gt=0)) > 0:
             yield subgraph
 
 
-def giant(collection: CachedCollection) -> Graph:
+def giant(collection: Collection) -> Graph:
     """
     Takes in a collection of bibliographic records and gets out the giant pre
     processed connected component.
 
-    :param CachedCollection collection: bibliographic collection
+    :param Collection collection: bibliographic collection
     :return: connected component graph
     """
     return next(load(collection), None)
